![Logo](https://github.com/RoySadaka/lpd/blob/master/images/logo.png)

lpd
====
A Fast, Flexible Trainer and Extensions for Pytorch

``lpd`` derives from the Hebrew word *lapid* (לפיד) which means "torch".


todos:
* expose evaluate method
* EpochEndStats - save best accuracies
* handle scheduler.step() that takes parameters
